#
# spec file for package powerline
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           powerline
Version:        2.6
Release:        1.2
Summary:        Status line and prompt utility
License:        MIT
Group:          System/Console
Url:            https://github.com/powerline/powerline
Source0:        https://github.com/powerline/powerline/archive/%{version}/powerline-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} >= 1330
BuildRequires:  python3-Sphinx
BuildRequires:  python3-base
BuildRequires:  python3-setuptools
%else
BuildRequires:  python
BuildRequires:  python-Sphinx
BuildRequires:  python-setuptools
%endif
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  sed
BuildRequires:  tmux
BuildRequires:  vim-base
%if 0%{?suse_version} >= 1330
%define powerline_python_sitelib %{python3_sitelib}
%else
%define powerline_python_sitelib %{python_sitelib}
%endif
%if 0%{?suse_version} >= 1330
Requires:       python3
#Requires:       python3-pygit2
%else
Requires:       python
Requires:       python-pygit2
%endif
Requires:       powerline-fonts

%description
Powerline is a status line plugin for vim, and provides status lines and prompts
for several other applications, including zsh, bash, tmux, IPython, Awesome and
Qtile.

%package fonts
BuildArch:      noarch
Summary:        Powerline Fonts
Group:          System/Console
Requires:       fontconfig

%description fonts
This package provides the powerline fonts.

%package docs
BuildArch:      noarch
Summary:        Documentation for powerline
Group:          System/Console

%description docs
This package provides the powerline documentation.

%package -n vim-plugin-powerline
BuildArch:      noarch
Summary:        Powerline VIM plugin
Group:          System/Console
Requires:       powerline
Requires:       vim

%description -n vim-plugin-powerline
Powerline is a status line plugin for vim, and provides status lines and
prompts.

%package -n tmux-powerline
BuildArch:      noarch
Summary:        Powerline for tmux
Group:          System/Console
Requires:       powerline
Requires:       tmux

%description -n tmux-powerline
Powerline for tmux.

Add

    source /usr/share/tmux/powerline.conf

to your ~/.tmux.conf file.

%prep
%setup -q

%build

%install
sed -i -e "/DEFAULT_SYSTEM_CONFIG_DIR/ s@None@'/etc/xdg'@" powerline/config.py
sed -i -e "/TMUX_CONFIG_DIRECTORY/ s@BINDINGS_DIRECTORY@'/usr/share'@" powerline/config.py
%if 0%{?suse_version} >= 1330
CFLAGS="%{optflags}" \
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot} --optimize=1
%else
CFLAGS="%{optflags}" \
python setup.py install --prefix=%{_prefix} --root=%{buildroot} --optimize=1
%endif

# build docs
pushd docs
make html SPHINXBUILD=/usr/bin/sphinx-build
rm _build/html/.buildinfo
# A structure gets initialized while building the docs with os.environ.
# This works around an rpmlint error with the build dir being in a file.
sed -i -e 's/abuild/user/g' _build/html/develop/extensions.html

make man SPHINXBUILD=/usr/bin/sphinx-build
popd

# config
install -d -m0755 %{buildroot}/%{_sysconfdir}/xdg/%{name}
cp -r powerline/config_files/* %{buildroot}/%{_sysconfdir}/xdg/%{name}/

# fonts
install -d -m0755 %{buildroot}/%{_sysconfdir}/fonts/conf.d
install -d -m0755 %{buildroot}/%{_datadir}/fonts/truetype
install -d -m0755 %{buildroot}/%{_datadir}/fontconfig/conf.avail

install -m0644 font/PowerlineSymbols.otf %{buildroot}/%{_datadir}/fonts/truetype/PowerlineSymbols.otf
install -m0644 font/10-powerline-symbols.conf %{buildroot}/%{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf

ln -s %{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf %{buildroot}/%{_sysconfdir}/fonts/conf.d/10-powerline-symbols.conf

# manpages
install -d -m0755 %{buildroot}/%{_datadir}/man/man1
for f in powerline-config.1 powerline-daemon.1 powerline-lint.1 powerline.1; do
	install -m0644 "docs/_build/man/$f" "%{buildroot}/%{_datadir}/man/man1/$f"
done

# awesome
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/awesome/
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/awesome/powerline.lua %{buildroot}/%{_datadir}/%{name}/awesome/
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/awesome/powerline-awesome.py %{buildroot}/%{_datadir}/%{name}/awesome/

# bash bindings
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/bash
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/bash/powerline.sh %{buildroot}/%{_datadir}/%{name}/bash/

# fish
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/fish
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/fish/powerline-setup.fish %{buildroot}/%{_datadir}/%{name}/fish

# i3
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/i3
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/i3/powerline-i3.py %{buildroot}/%{_datadir}/%{name}/i3

# ipython
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/ipython
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/ipython/post_0_11.py %{buildroot}/%{_datadir}/%{name}/ipython
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/ipython/pre_0_11.py %{buildroot}/%{_datadir}/%{name}/ipython

# qtile
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/qtile
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/qtile/widget.py %{buildroot}/%{_datadir}/%{name}/qtile

# shell bindings
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/shell
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/shell/powerline.sh %{buildroot}/%{_datadir}/%{name}/shell/

# tcsh
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/tcsh
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/tcsh/powerline.tcsh %{buildroot}/%{_datadir}/%{name}/tcsh

# tmux plugin
install -d -m0755 %{buildroot}/%{_datadir}/tmux
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/tmux/powerline*.conf %{buildroot}/%{_datadir}/tmux/

# vim plugin
install -d -m0755 %{buildroot}/%{_datadir}/vim/site/plugin/
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/vim/plugin/powerline.vim %{buildroot}/%{_datadir}/vim/site/plugin/powerline.vim
rm -rf %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/vim/plugin
install -d -m0755 %{buildroot}/%{_datadir}/vim/site/autoload/powerline
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/vim/autoload/powerline/debug.vim %{buildroot}/%{_datadir}/vim/site/autoload/powerline/debug.vim
rm -rf %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/vim/autoload

# zsh
install -d -m0755 %{buildroot}/%{_datadir}/%{name}/zsh
mv %{buildroot}/%{powerline_python_sitelib}/powerline/bindings/zsh/powerline.zsh %{buildroot}/%{_datadir}/%{name}/zsh

# cleanup
rm -rf %{buildroot}/%{powerline_python_sitelib}/%{name}/config_files
find %{buildroot}/%{powerline_python_sitelib}/%{name}/bindings -name "*.py[a-z]" -delete

%fdupes %{buildroot}%{powerline_python_sitelib}

%files
%defattr(-,root,root)
%doc LICENSE README.rst
%config %{_sysconfdir}/xdg/%{name}
%{_bindir}/powerline
%{_bindir}/powerline-config
%{_bindir}/powerline-daemon
%{_bindir}/powerline-render
%{_bindir}/powerline-lint
%{_mandir}/man1/powerline.1*
%{_mandir}/man1/powerline-config.1*
%{_mandir}/man1/powerline-daemon.1*
%{_mandir}/man1/powerline-lint.1*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/awesome
%{_datadir}/%{name}/awesome/powerline.lua
%{_datadir}/%{name}/awesome/powerline-awesome.py
%dir %{_datadir}/%{name}/bash
%{_datadir}/%{name}/bash/powerline.sh
%dir %{_datadir}/%{name}/fish
%{_datadir}/%{name}/fish/powerline-setup.fish
%dir %{_datadir}/%{name}/i3
%{_datadir}/%{name}/i3/powerline-i3.py
%dir %{_datadir}/%{name}/ipython
%{_datadir}/%{name}/ipython/post_0_11.py
%{_datadir}/%{name}/ipython/pre_0_11.py
%dir %{_datadir}/%{name}/qtile
%{_datadir}/%{name}/qtile/widget.py
%dir %{_datadir}/%{name}/shell
%{_datadir}/%{name}/shell/powerline.sh
%dir %{_datadir}/%{name}/tcsh
%{_datadir}/%{name}/tcsh/powerline.tcsh
%dir %{_datadir}/%{name}/zsh
%{_datadir}/%{name}/zsh/powerline.zsh
%{powerline_python_sitelib}/*

%files fonts
%defattr(-,root,root)
%doc LICENSE README.rst
%{_sysconfdir}/fonts/conf.d/10-powerline-symbols.conf
%{_datadir}/fontconfig/conf.avail/10-powerline-symbols.conf
%dir %{_datadir}/fonts/truetype
%{_datadir}/fonts/truetype/PowerlineSymbols.otf

%files docs
%defattr(-,root,root)
%doc docs/_build/html

%files -n vim-plugin-powerline
%defattr(-,root,root)
%doc LICENSE README.rst
%dir %{_datadir}/vim/site/autoload
%dir %{_datadir}/vim/site/autoload/powerline
%{_datadir}/vim/site/autoload/powerline/debug.vim
%dir %{_datadir}/vim/site/plugin
%{_datadir}/vim/site/plugin/powerline.vim

%files -n tmux-powerline
%defattr(-,root,root)
%doc LICENSE README.rst
%dir %{_datadir}/tmux
%{_datadir}/tmux/powerline*.conf

%changelog
* Wed May 10 2017 asn@cryptomilk.org
- Update to version 2.6:
  * Added support for new Vim modes.
  * Added ability to control output padding.
  * Added iTunes player segment.
  * Added support for tmux development builds.
  * Added a workaround for a fish bug sometimes occurring when using eval from
  * config.fish (upstream status unknown).
  * Added a workaround for tmux 2.4 bug: excessive CPU usage when having multiple
  * panes (also fixed upstream).
  * Fixed clean file status support in mercurial.
  * Fixed error when battery capacity is zero and using DBus.
  * Fixed mercurial command servers leakage.
  * Refactored awesome bindings to use powerline daemon.
* Fri Apr  7 2017 jengelh@inai.de
- Improve package summary.
- Avoid unnecessary %%__-type macro indirections.
  Replace find -exec rm by just find -delete.
* Tue Mar 28 2017 lbeltrame@kde.org
- Reformat spec properly
- Add a license
* Fri Feb 10 2017 asn@cryptomilk.org
- Update to version 2.5.2:
  * Fixed ipython-5.2* support.
  * Made more robust theme default.
  * Made it use hglib in place of unstable mercurial plugin API.
  * Fixed latest fish version support.
  * Some other fixes and documentation adjustments.
* Wed Jul 27 2016 fcrozat@suse.com
- Update to version 2.5:
  * Fix trailing whitespace segment on Python 3.
  * Fix left segments support in tmux-2.1
  * Add support for IPython-5
  * Increase socket backlog number for `powerline-daemon`
  * Use different query to retrieve weather
  * implement stash backend for git
  * provide stash counter
  * include stash in default shell layout
  * expose stash to Vim
* Tue Apr 19 2016 asn@cryptomilk.org
- Update to version 2.4
  * Added short parameter for system_load segment that leaves only one load
    average number out of three.
  * Added powerline.segments.i3wm.scratchpad segment used to list windows
    that are currently on the scratchpad.
  * Added support for multiple batteries in battery segment.
  * Added ….i3wm.workspace segment which describes single i3wm workspace and
    workspaces lister. Old .i3wm.workspaces segment was deprecated.
  * Added support for multiple monitors in lemonbar bindings.
  * Added support for most recent tmux version (2.2).
  * Fixed battery status support on some linux systems.
  * Fixed MPD bindings: they sometimes were not able to handle names if they
    did not fit ASCII.
  * Fixed MPD bindings: they did not correctly get elapsed time.
  * Fixed AttributeError on some systems: LC_MESSAGES is not always available.
  * Fixed Mac OS-specific variant of spotify player support when Python-3 is used.
  * Fixed performance of the tabline.
* Tue Oct 20 2015 asn@cryptomilk.org
- Update to version 2.3
  * Added ability to hide domain part of the user name to common.env.user segment.
  * Added ability to show conda environment to virtualenv segment.
  * Added systemd service file.
  * Added ability to detect internal_ip interface using default gateway.
  * Added support for password-protected connections in mpd player bindings.
  * Added `output` option to i3wm.workspaces segment to filter workspaces based on
    their output.
  * Added “charging” indicator to battery segment.
  * Made tmux bindings show zoom indicator in window status.
  * Fixed tmux bindings so that they support tmux-2.1.
  * Fixed support for unicode characters in common.time.date segment.
* Mon Jul  6 2015 asn@cryptomilk.org
- Update to version 2.2
  * Added support for newest psutil version.
  * Added support for non-SSL IMAP4 connection.
  * Added support for clickable tab names in Vim.
  * Added support for truncating tmux segments.
  * Added support for new (i3ipc) module that interacts with i3.
  * Added support for i3 modes.
  * Fixed coloring of network_load segment.
  * Fixed dash bindings on OS X.
  * Fixed parsing numbers starting with 2 supplied by POWERLINE_*_OVERRIDES
    environment variables.
* Tue May 12 2015 asn@cryptomilk.org
- Update to version 2.1.4
  * Added support for placing powerline on the left in qtile.
  * Added qtile-1.9 support.
  * Fixed tmux-2.0 support.
  * Made it easier to run tests outside of travis.
  * Added some missing highlight groups.
  * Made it omit writing empty above lines.
  * Fixed UnicodeEncodeError when running powerline-lint with non-ASCII
    characters in error messages.
  * Fixed code that replaces &statusline value: it now is able to replace
    non-ASCII &statuslines as well.
  * Fixed powerline-render arguments parsing.
* Fri Feb 20 2015 asn@cryptomilk.org
- Update to version 2.1
  * Added BAR support.
  * Added support for pdb (Python debugger) prompt.
  * Added more highlight groups to solarized colorscheme.
  * Updated zpython bindings.
  * Fixed C version of the client on non-Linux platforms.
  * Fixed some errors in powerline-lint code.
  * Fixed Python-2.6 incompatibilities in setup.py.
* Tue Jan 20 2015 asn@cryptomilk.org
- Update to version 2.0
  * Added fbterm (framebuffer terminal emulator) support.
  * Added theme with unicode-7.0 symbols.
  * Added support for PyPy3.
  * Compiler is now called with CFLAGS from environment in setup.py if present.
  * Added support for pyuv-1.*.
  * Added a way to write error log to Vim global variable.
  * powerline script now supports overrides from $POWERLINE_CONFIG_OVERRIDES,
    $POWERLINE_THEME_OVERRIDES environment variables, so does powerline-config
    script.
  * powerline and powerline-config scripts now support taking paths from
    $POWERLINE_CONFIG_PATHS.
  * powerline-lint is now able to report dictionaries which were merged in to
    form marked dictionary and what were the previous values of overridden
    values.
  * Added support for Byron Rakitzis’ rc shell reimplementation.
  * Added support for querying battery status on cygwin platform.
* Tue Dec  9 2014 asn@cryptomilk.org
- Update to version 1.3.1
- Fixed some packaging issues.
- Added patch to support CFLAGS.
* Thu Dec  4 2014 asn@cryptomilk.org
- Fix powerline-config.
* Tue Dec  2 2014 asn@cryptomilk.org
- Update to version 1.3.
* Wed Aug 13 2014 asn@cryptomilk.org
- Fix package type.
* Wed Aug 13 2014 asn@cryptomilk.org
- Update to revisiion 7453e58680c27a3435fd95d03f502d25eb80e98b.
* Wed May  7 2014 asn@cryptomilk.org
- Update to revision 9e7c6cf0bed52e47451c81377b5a1a96366b053f.
* Wed Mar 12 2014 asn@cryptomilk.org
- Update to revision 70a94ee7d39a0958a06436aaeba05bd830830cc8.
* Sun Feb  9 2014 asn@cryptomilk.org
- Update to 999fad58bd493c0f37233eb7941508af220d945e.
* Mon Dec  2 2013 asn@cryptomilk.org
- Improve the spec file.
* Sun Nov 24 2013 asn@cryptomilk.org
- Add missing window marker to tmux status line.
* Sun Nov 24 2013 asn@cryptomilk.org
- Install and package python files.
- Build documentation.
* Sat Nov 23 2013 asn@cryptomilk.org
- Initial package.
